# 更新日志

OpenViking 的所有重要变更都将记录在此文件中。

格式基于 [Keep a Changelog](https://keepachangelog.com/zh-CN/1.0.0/)，
本项目遵循 [语义化版本](https://semver.org/lang/zh-CN/)。

## [未发布]

### 新增
- 首次公开发布
- 核心上下文数据库功能
- 三层信息模型 (L0/L1/L2)
- Viking URI 系统
- 会话管理与记忆提取
- 多模态资源支持（图片、视频、音频）
- 技能管理与 MCP 工具转换

### 变更
- 无

### 弃用
- 无

### 移除
- 无

### 修复
- 无

### 安全
- 无

---

## 版本历史格式

每个版本将包含：

### 新增
新功能和新特性。

### 变更
对现有功能的修改。

### 弃用
将在未来版本中移除的功能。

### 移除
已移除的功能。

### 修复
Bug 修复。

### 安全
安全相关的变更。
